@@ -245,6 +245,32 @@ class APRSMessage
     return longitude
   end
 
+  
+  def is_message?
+    @@logger.info( "is_message?( message)")
+
+    type = false
+
+    if payload.length > 0 
+      type = payload[0].chr
+    end
+
+    return type == ':'
+  end
+
+  
+  def is_query?
+    @@logger.info( "is_query?( message)")
+
+    type = false
+
+    if payload.length > 0 
+      type = payload[0].chr
+    end
+
+    return type == '?'
+  end
+
 
   def to_s
     buffer = String.new
