@@ -54,8 +54,8 @@ class AX25Socket
   def initAX25Socket()
     @@logger.info( "initAX25Socket")
 
-    if @mode == "kiss"
-      @socket = KISSDevice.new( @device, @call, @speed, @timeout)
+    if @mode.index( "kiss") == 0 
+      @socket = KISSDevice.new( @device, @call, @speed, @timeout, @mode)
     end
 
     return
