@@ -22,12 +22,12 @@ require 'aprs4r/SocketConfiguration'
 
 class AX25SocketConfiguration < SocketConfiguration
 
-  attr_reader :device, :mode, :call
-  attr_writer :device, :mode, :call
+  attr_reader :device, :mode, :call, :speed, :timeout
+  attr_writer :device, :mode, :call, :speed, :timeout
 
 
   def to_yaml_properties
-    %w{ @device @mode @call}
+    %w{ @device @mode @call @speed}
   end
 
 end
