@@ -18,6 +18,7 @@
 #
 
 require 'aprs4r/APRSCall'
+require 'aprs4r/ConfigurationAttribute'
 
 class BeaconConfiguration
 
@@ -29,4 +30,23 @@ class BeaconConfiguration
     %w{ @name @enable @device @period @offset @message}
   end
 
+  
+  def attributes 
+
+    print "attributes\n"
+
+    attributes = Array.new
+    
+    attributes << ConfigurationAttribute.new( "name", 1, "text", "scalar", "Name", 10)
+    attributes << ConfigurationAttribute.new( "enable", 2, "radio", "scalar", "Aktivieren", 0)
+
+    attributes << ConfigurationAttribute.new( "device", 3, "text", "scalar", "Geraet", 10)
+    attributes << ConfigurationAttribute.new( "period", 4, "text", "scalar", "Periode", 5)
+    attributes << ConfigurationAttribute.new( "offset", 5, "text", "scalar", "Offset", 5)
+
+    return attributes
+  end
+    
+  
+
 end
