@@ -58,6 +58,7 @@ class ISSocket
       @duplicatePeriod = configuration.duplicatePeriod
     else 
       # socket server mode 
+      @enable = true
       @clientMode = false
 
       @socket = socket
@@ -197,6 +198,8 @@ class ISSocket
         if @socket
           line = @socket.gets
         end
+
+        @@logger.debug( "readData::line: -#{line}-")
         
         # if nil, an exception is raised (and reinit is started)
         line.chomp!
@@ -235,18 +238,18 @@ class ISSocket
       sourceIndex = header.index( '>')
       
       if sourceIndex != nil 
-        message.source = APRSCall.parse( header[0...sourceIndex])
+        message.source = APRSCall.parse( header[0...sourceIndex]).to_s
       end
 
       # path
       message.path = Array.new
       path = header[sourceIndex+1...header.length].split( ',')
-      message.destination = APRSCall.parse( path[0]) 
+      message.destination = APRSCall.parse( path[0]).to_s
 
       path.delete( 0)
       
       path.each{ |entry|
-        call = APRSCall.parse( entry)
+        call = APRSCall.parse( entry).to_s
         message.path << call
       }
 
