@@ -67,11 +67,11 @@ class KISSDevice
       
       @port.flow_control = SerialPort::SOFT
 
-      if mode.index( "tnc2/northlink") != nil
+      if @mode.index( "tnc2/northlink") != nil
         initTNC2Northlink
-      elsif mode.index( "tnc2/tapr") != nil
+      elsif @mode.index( "tnc2/tapr") != nil
         initTNC2TAPR
-      elsif mode.index( "kenwood") != nil
+      elsif @mode.index( "kenwood") != nil
         initKenwood
       else
         initDefault
@@ -98,14 +98,14 @@ class KISSDevice
     # send exit frame 
     data = String.new
       
-    data << @@FEND
-    data << 0xFF
-    data << @@FEND
-    data << "\r" 
+#    data << @@FEND
+#    data << 0xFF
+#    data << @@FEND
+#    data << "\r" 
 
-    @@logger.debug( "send KISS exit frame");
-    @port.write( data)
-    sleep 1
+#    @@logger.debug( "send KISS exit frame");
+#    @port.write( data)
+#    sleep 1
 
     data = String.new
     data << ?\C-X
