@@ -139,7 +139,7 @@ class SocketManager
 
     if ! listeners.nil?
       listeners.each{ |listener|
-        listener.receiveAPRSMessage( message.clone)
+        listener.receiveAPRSMessage( name, message.clone)
       }
     end
 
